WITH csrAnnualSales (SalesPersonID, OrderYear, TotalSales)
AS
(SELECT SalesPersonID, YEAR(OrderDate), SUM(SubTotal) AS TotalSales
  FROM [Sales].[SalesOrderHeader]
  WHERE SalesPersonID IS NOT NULL
  GROUP BY SalesPersonID, YEAR(OrderDate))

SELECT SalesPersonID, OrderYear, TotalSales,
       CUME_DIST() OVER (PARTITION BY OrderYear ORDER BY TotalSales) AS CumeDist,
       PERCENT_RANK() OVER (PARTITION BY OrderYear ORDER BY TotalSales) AS PctRank,
       RANK() OVER (PARTITION BY OrderYear ORDER BY TotalSales) AS Rank,
       COUNT(SalesPersonID) OVER 
         (PARTITION BY OrderYear ORDER BY TotalSales 
          RANGE BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS GroupCount,
       CAST(1.00 * RANK() OVER 
         (PARTITION BY OrderYear ORDER BY TotalSales) /  
         COUNT(SalesPersonID) OVER 
            (PARTITION BY OrderYear ORDER BY TotalSales 
             RANGE BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) 
         AS decimal(5,2)) AS ComputedDist
  FROM csrAnnualSales;
