WITH csrYearlySales (OrderYear, ProductID, NumSold)
AS 

(SELECT YEAR(OrderDate) AS OrderYear, ProductID, SUM(OrderQty) AS NumSold
   FROM Sales.SalesOrderHeader SOH
     JOIN Sales.SalesOrderDetail SOD
       ON SOH.SalesOrderID = SOD.SalesOrderID
   GROUP BY YEAR(OrderDate), ProductID)

SELECT ProductID, OrderYear, NumSold,
       FIRST_VALUE(NumSold) OVER 
         (PARTITION BY ProductID ORDER BY NumSold) AS MinSold,
       FIRST_VALUE(OrderYear) OVER 
         (PARTITION BY ProductID ORDER BY NumSold) AS MinYear,
       LAST_VALUE(NumSold) OVER 
         (PARTITION BY ProductID ORDER BY NumSold 
          RANGE BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS MaxSold,
       LAST_VALUE(OrderYear) OVER 
         (PARTITION BY ProductID ORDER BY NumSold 
          RANGE BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS MaxYear
  FROM csrYearlySales
  ORDER BY ProductID, OrderYear;
